@@ -36,7 +36,7 @@
 
 #define TX_RAW_CLASS   "Text::Xslate::Type::Raw"
 #define TX_PAIR_CLASS  "Text::Xslate::Type::Pair"
-#define TX_MACRO_CLASS "Text::Xslate::Macro"
+#define TX_MACRO_CLASS "Text::Xslate::Type::Macro"
 
 /* arbitrary initial buffer size */
 #define TX_HINT_SIZE 128
